@@ -10,8 +10,17 @@ from models import Article, Tag
 from forms import CommentForm
 
 def list_baseview(request, article_qs, template="simpleblog/list_view.html"):
+    try: page = int(request.GET["page"])
+    except: page = 0
+    try: limit = int(request.GET["limit"])
+    except: limit = 10
+
+    pagination = range((article_qs.count()/limit)+1)
+
+    article_qs = article_qs[page*limit:page*limit+limit]
+
     return render_to_response(template,
-        {"article_qs":article_qs, },
+        {"article_qs":article_qs, "pagination": pagination, "limit": limit, "actual_page": page, },
         context_instance=RequestContext(request))
 
 def home_view(request):
